{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "awk",
            "doc": "AWK command",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:18.04",
                    "id": "#ubuntu-docker.yml"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Awk separator",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    },
                    "id": "#awk.cwl/F"
                },
                {
                    "type": "File",
                    "doc": "Input file",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#awk.cwl/file"
                },
                {
                    "type": "string",
                    "doc": "Out put file name",
                    "id": "#awk.cwl/outFileName"
                },
                {
                    "type": "string",
                    "doc": "Awk text",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#awk.cwl/text"
                }
            ],
            "stdout": "$(inputs.outFileName)",
            "baseCommand": [
                "awk"
            ],
            "id": "#awk.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#awk.cwl/output",
                    "outputBinding": {
                        "glob": "$(inputs.outFileName)"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "gzip",
            "doc": "Compress files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "$import": "#ubuntu-docker.yml"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-d"
                    },
                    "id": "#gzip.cwl/d"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#gzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.d){\n    return inputs.file.nameroot;\n  }else{\n    return inputs.file.basename + '.gz';\n  }\n}\n"
                    },
                    "id": "#gzip.cwl/output"
                }
            ],
            "stdout": "${\n    if (inputs.d){\n        return inputs.file.nameroot;\n    }else{\n        return inputs.file.basename + '.gz';\n    }\n}\n",
            "baseCommand": [
                "gzip",
                "-c"
            ],
            "id": "#gzip.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "bedtools-bamtobed",
            "doc": "The bedtools utilities are a swiss-army knife of tools for a wide-range of genomics analysis tasks",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/bedtools:2.28.0--hdf88d34_0",
                    "id": "#bedtools-docker.yml"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "package": "bedtools",
                            "version": [
                                "2.29.2"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/bedtools"
                            ]
                        }
                    ],
                    "id": "#bedtools-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-bed12"
                    },
                    "doc": "Write \u201cblocked\u201d BED (a.k.a. BED12) format. This will convert \u201cspliced\u201d BAM alignments\n(denoted by the \u201cN\u201d CIGAR operation) to BED12. Forces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/bed12"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bedpe"
                    },
                    "doc": "Write BAM alignments in BEDPE format. Only one alignment from paired-end reads will be reported.\nSpecifically, it each mate is aligned to the same chromosome, the BAM alignment reported will\nbe the one where the BAM insert size is greater than zero. When the mate alignments are\ninterchromosomal, the lexicographically lower chromosome will be reported first. Lastly,\nwhen an end is unmapped, the chromosome and strand will be set to \u201c.\u201d and the start and\nend coordinates will be set to -1. By default, this is disabled and the output will be\nreported in BED format.\n",
                    "id": "#bedtools-bamtobed.cwl/bedpe"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-i"
                    },
                    "doc": "Input BAM format",
                    "id": "#bedtools-bamtobed.cwl/i"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-mate1"
                    },
                    "doc": "When writing BEDPE (-bedpe) format, always report mate one as the first BEDPE \u201cblock\u201d.\n",
                    "id": "#bedtools-bamtobed.cwl/mate1"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-split"
                    },
                    "doc": "Report each portion of a \u201csplit\u201d BAM (i.e., having an \u201cN\u201d CIGAR operation) alignment as\na distinct BED intervals.\n",
                    "id": "#bedtools-bamtobed.cwl/split"
                },
                {
                    "type": "string",
                    "doc": "Stdout from program",
                    "id": "#bedtools-bamtobed.cwl/stdout"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.stdout)"
                    },
                    "id": "#bedtools-bamtobed.cwl/out_stdout"
                }
            ],
            "stdout": "$(inputs.stdout)",
            "baseCommand": [
                "bedtools",
                "bamtobed"
            ],
            "id": "#bedtools-bamtobed.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "label": "Create tagAlign file",
            "doc": "This workflow creates tagAlign file",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bam_file"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/gzip/output",
                    "type": "File",
                    "id": "#main/output"
                }
            ],
            "steps": [
                {
                    "run": "#awk.cwl",
                    "in": [
                        {
                            "source": "#main/bamtobed/out_stdout",
                            "id": "#main/awk/file"
                        },
                        {
                            "valueFrom": "${ return inputs.file.nameroot + \".tagAlign\";}",
                            "id": "#main/awk/outFileName"
                        },
                        {
                            "default": "BEGIN{OFS=\"\\t\"}{$4=\"N\";$5=\"1000\";print $0}",
                            "id": "#main/awk/text"
                        }
                    ],
                    "out": [
                        "#main/awk/output"
                    ],
                    "id": "#main/awk"
                },
                {
                    "run": "#bedtools-bamtobed.cwl",
                    "in": [
                        {
                            "source": "#main/bam_file",
                            "id": "#main/bamtobed/i"
                        },
                        {
                            "valueFrom": "${ return inputs.i.nameroot + \".bed\";}",
                            "id": "#main/bamtobed/stdout"
                        }
                    ],
                    "out": [
                        "#main/bamtobed/out_stdout"
                    ],
                    "id": "#main/bamtobed"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#main/awk/output",
                            "id": "#main/gzip/file"
                        }
                    ],
                    "out": [
                        "#main/gzip/output"
                    ],
                    "id": "#main/gzip"
                }
            ],
            "id": "#main",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ],
            "http://schema.org/license": "https://spdx.org/licenses/OPL-1.0"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf",
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
